@@ -16,7 +16,9 @@ modlabel = function(name, pad=2, ...){
 match_arg = function(arg,
                      choices,
                      several.ok = FALSE,
+                     max_choice = 2,
                      pos = -1) {
+
      cal = sys.call(pos)
      def = sys.function(pos)
 
@@ -191,38 +193,54 @@ set.defaults = function(de.list, de.names, de.values) {
      return(de.list)
 }
 
-# function that determines if column is factor. This will only work on a model
-# matrix as generated by the model.matrix() function, and is intended for internal
-# use only. 
-detect_factors = function(x){
-  if(length(unique(x)) == 1 || all(x == 1 | x == 0))
-    return(TRUE)
-  else
-    return(FALSE)
-}
 
 
-scaler = function(mat, scaling = 1){
-  
-  if(is.null(mat)) 
-    return(NULL)
-  
-  to_scale = !apply(mat, 2, detect_factors)
-  
+
+
+scaler = function(df, scaling = 1){
+
+  to_scale = !(sapply(df, function(col) length(unique(col)) %in% c(1,2) || is.character(col) || is.factor(col))
+               | grepl("^offset\\(|^\\(weights\\)$", names(df)))
+
+  to_scale[c(1,2)] = c(F,F) # first two are always outcome vectors, never scale them.
+
+  if(sum(to_scale) == 0)
+       return(df)
+
   if(scaling == 3) {
-    mn = apply(mat[, to_scale], 2, min)
-    mx = apply(mat[, to_scale], 2, max)
+    mn = apply(df[, to_scale, drop=F], 2, min)
+    mx = apply(df[, to_scale, drop=F], 2, max)
   }
-  
-  mat[,to_scale] = switch(
+
+  df[,to_scale] = switch(
     scaling,
-    scale(mat[,to_scale], center = T, scale = T),
-    scale(mat[,to_scale], center = T, scale = T)/2,
-    scale(mat[,to_scale], center = mn, scale = (mx - mn))
+     scale(df[,to_scale], center = T, scale = T),
+     scale(df[,to_scale], center = T, scale = T)/2,
+     scale(df[,to_scale], center = mn, scale = (mx - mn))
   )
-  
-  
-  attr(mat, "scaled") = colnames(mat)[to_scale]
-  return(mat)
+
+
+  attr(df, "scaled") = names(to_scale)[to_scale]
+  return(df)
 }
 
+
+
+
+vprob = function(x, eq = 'both'){
+     eq = match_arg(eq, choices = c("both", "left", "right"))
+
+     out = if(!is.null(x)){
+          switch(eq,
+                 "both" = x <= 1 & x >= 0,
+                 "left" = x < 1 & x >= 0,
+                 "right" = x <= 1 & x > 0)
+     }
+     else{
+          TRUE
+     }
+
+
+     return(out)
+
+}
